==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Effect/soxr/translations/soxr_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation>SoX-Abtastratenkonvertierermodul</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Über SoX-Abtastratenkonvertierermodul</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Qmmp SoX-Abtastratenkonvertierermodul</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Einstellungen Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Abtastrate (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Schnell</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Sehr hoch</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/Effect/soxr/translations/soxr_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="30"/>
        <source>SoX Resampler Plugin</source>
        <translation>SoX-Abtastratenkonvertierermodul</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="50"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Über SoX-Abtastratenkonvertierermodul</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="51"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Qmmp SoX-Abtastratenkonvertierermodul</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SoXRSettingsDialog</name>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Einstellungen Abtastratenkonverter-Modul</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Abtastrate (Hz):</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.ui" line="40"/>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Schnell</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <location filename="../soxrsettingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Sehr hoch</translation>
    </message>
</context>
</TS>
